@@ -21,9 +21,9 @@
 #ifndef ALLYOURBASE_H
 #define ALLYOURBASE_H
 
-#include <kwallet.h>
-#include <kiconloader.h>
-#include <kicontheme.h>
+#include <KWallet>
+#include <KIconLoader>
+#include <KIconTheme>
 #include <QListWidget>
 
 #include <QPixmap>
